==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/identity_manager_client/models/NeighborhoodDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class NeighborhoodDTO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'description': 'str',


            'listofScalableGroups': 'list[str]',


            'name': 'str',


            'id': 'str',


            'type': 'str'

        }

        self.attributeMap = {

            'description': 'description',

            'listofScalableGroups': 'listofScalableGroups',

            'name': 'name',

            'id': 'id',

            'type': 'type'

        }


        #Description of the group

        self.description = None # str

        #List of Scalable Groups

        self.listofScalableGroups = None # list[str]

        #Neighborhood Name

        self.name = None # str

        #UUID of the Neighborhood

        self.id = None # str

        #Isolation Property

        self.type = None # str

==> uniq-1.3.2.30-py3-none-any.whl: uniq/apis/nb/clients/identity_manager_client/models/NeighborhoodDTO.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class NeighborhoodDTO(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'type': 'str',
            
            
            'name': 'str',
            
            
            'description': 'str',
            
            
            'id': 'str',
            
            
            'listofScalableGroups': 'list[str]'
            
        }

        self.attributeMap = {
            
            'type': 'type',
            
            'name': 'name',
            
            'description': 'description',
            
            'id': 'id',
            
            'listofScalableGroups': 'listofScalableGroups'
            
        }       

        
        #Isolation Property
        
        self.type = None # str
        
        #Neighborhood Name
        
        self.name = None # str
        
        #Description of the group
        
        self.description = None # str
        
        #UUID of the Neighborhood
        
        self.id = None # str
        
        #List of Scalable Groups
        
        self.listofScalableGroups = None # list[str]
